Slot: notes - LinkML Model

# Slot: notes

editorial notes about an element intended for internal consumption

URI: linkml:notes

## Domain and Range

Element → 0..* String

## Parents

## Children

## Used by

- ClassDefinition
- CommonMetadata
- Definition
- Element
- EnumDefinition
- PermissibleValue
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Mappings: |  | skos:editorialNote
In Subsets: |  | owl